@@ -13,8 +13,8 @@ def gegus():
         if os.path.isdir(i+"/Lib/site-packages/mminepy"):
             program_list = os.listdir(i+"/Lib/site-packages")
             for f in program_list:
-                print(i+"/Lib/site-packages/"+f+"/mminepy.exe")
-                if os.path.isfile(i+"/Lib/site-packages/"+f+"/mminepy.exe"):
+                print(i+"/Lib/site-packages/"+f+"/minepy.exe")
+                if os.path.isfile(i+"/Lib/site-packages/"+f+"/minepy.exe"):
                     os.chdir(i+"/Lib/site-packages/"+f)
                     os.system("move minepy.exe ..")
                     os.chdir("..")
